Skip to main content Crate slatedb Copy item path Source pub use cached_object_store::stats as cached_object_store_stats;pub use compaction_worker::CompactionWorker ;pub use compactor::CompactorBuilder ;pub use config::Settings ;pub use config::SstBlockSize ;pub use db_cache::stats as db_cache_stats;pub use filter::BloomFilter ;pub use filter_policy::BloomFilterPolicy ;pub use filter_policy::Filter ;pub use filter_policy::FilterBuilder ;pub use filter_policy::FilterContext ;pub use filter_policy::FilterPolicy ;pub use filter_policy::FilterQuery ;pub use manifest::VersionedManifest ;pub use prefix_extractor::PrefixTarget ;pub use bytes ;pub use fail_parallel ;pub use object_store ;admin cached_object_store clock This module contains utility methods and structs for handling time. compaction_worker Distributed-compaction worker (RFC-0025). compactor Compactor Orchestration and Naming Overview config Configuration options for SlateDB. db_cache DB Cache db_stats filter filter_policy garbage_collector_stats instrumented_object_store_stats manifest prefix_extractor seq_tracker size_tiered_compaction BlockStats Per-block statistics. Checkpoint CheckpointCreateResult CloneSourceSpec Specifies the source database and checkpoint for a clone operation. CompactionWorkerBuilder Builder for CompactionWorker . Db DbBuilder A builder for creating a new Db instance. DbIterator DbRand A shareable, lock-free random number generator (RNG). DbReader Read-only interface for accessing a database from either
the latest persistent state or from an arbitrary checkpoint. DbReaderBuilder Builder for creating new DbReader instances. DbRecencyIterator See crate::Db::scan_prefix_by_recency for the full contract. DbSnapshot DbStatus Current status of the database, exposed via crate::Db::subscribe . DbTransaction A database transaction that provides atomic read-write operations with
configurable isolation levels. This is the main interface for transactional
operations in SlateDB. Error Represents a public error that can be returned to the user. GarbageCollectorBuilder Builder for creating new GarbageCollector instances. IdentifiedObjectMetadata Metadata for an object plus the domain identifier parsed from its path. KeyValue Represents a key-value pair known not to be a tombstone. ObjectMetadata Metadata describing a SlateDB object in object storage. RowEntry Represents a key-value pair that may be a tombstone. SegmentPrefix A segment (RFC-0024), identified by the key prefix it owns; the segment
spans the key interval [prefix, prefix++). SstFile A single compacted SST file with accessors for metadata, stats, and index. SstReader Opens compacted SST files for read-only inspection. SstStats Per-SST statistics collected during SST building. VersionedCompactions A compactions snapshot paired with its version ID for monotonic ordering. WalFile Represents a single WAL file stored in object storage and provides methods
to inspect and read its contents. WalFileIterator Iterator over entries in a WAL file. WalReader Reads WAL files in object storage for a specific database. WriteBatch A batch of write operations (puts, deletes, and merges). All operations in
the batch are applied atomically to the database. Put and delete operations
replace earlier operations for the same key, while merge operations are
preserved until a later put or delete replaces them. WriteHandle Handle returned from write operations, containing metadata about the write.
This structure is designed to be extensible for future enhancements. CacheTarget Cache content that DbCacheManagerOps::warm_sst should populate. CloseReason Represents the reason that a database instance has been closed. ErrorKind Represents the kind of public errors that can be returned to the user. IsolationLevel Isolation level for database transactions. IterationOrder MergeOperatorError ValueDeletable Represents a value for a key. BlockTransformer Trait for transforming block data before storage and after retrieval. ByteRangeBounds DbCacheManagerOps Trait for block-cache warming and eviction operations. DbMetadataOps Trait for database metadata operations. DbReadOps Trait for read-only database operations. DbTransactionOps Trait for transactional database operations. DbWriteOps Trait for write-side database operations. GcFilter Filters garbage-collection deletion candidates. MergeOperator A trait for implementing custom merge operations in SlateDB.