pub struct CachedObjectStoreBuilder { /* private fields */ }Expand description
Builder for CachedObjectStore. Created by CachedObjectStore::builder.
Implementations
Sourceimpl CachedObjectStoreBuilder
impl CachedObjectStoreBuilder
Sourcepub fn with_max_cache_size_bytes(
self,
max_cache_size_bytes: Option<usize>,
) -> Self
pub fn with_max_cache_size_bytes( self, max_cache_size_bytes: Option<usize>, ) -> Self
Sets the limit of the cache size in bytes.
None disables eviction and the default is 16gb.
Sourcepub fn with_part_size_bytes(self, part_size_bytes: usize) -> Self
pub fn with_part_size_bytes(self, part_size_bytes: usize) -> Self
Sets the size of each part file. Must be a multiple of 1kb.
The default is 4mb.
Sourcepub fn with_cache_on_flush(self, cache_on_flush: bool) -> Self
pub fn with_cache_on_flush(self, cache_on_flush: bool) -> Self
Sets whether compacted SSTs produced by memtable flushes are admitted to the cache on write.
The default is false.
Sourcepub fn with_cache_on_compaction(self, cache_on_compaction: bool) -> Self
pub fn with_cache_on_compaction(self, cache_on_compaction: bool) -> Self
Sets whether compacted SSTs produced by compaction are admitted to the cache on write.
The default is false.
Sourcepub fn with_scan_interval(self, scan_interval: Option<Duration>) -> Self
pub fn with_scan_interval(self, scan_interval: Option<Duration>) -> Self
Sets the interval at which the cache directory is scanned to rebuild the evictor’s in-memory map.
None scans only once on startup and the default is 1 hour.
Sourcepub fn with_max_open_file_handles(self, max_open_file_handles: usize) -> Self
pub fn with_max_open_file_handles(self, max_open_file_handles: usize) -> Self
Sets the maximum number of open file handles kept by the part file handle cache.
The default is 1000.
Sourcepub fn with_metrics_recorder(
self,
metrics_recorder: Arc<dyn MetricsRecorder>,
) -> Self
pub fn with_metrics_recorder( self, metrics_recorder: Arc<dyn MetricsRecorder>, ) -> Self
Sets the recorder for the cache’s metrics (hit and access counters, cache size gauges, eviction counters).
Defaults to a no-op recorder.
Sourcepub fn with_metric_level(self, metric_level: MetricLevel) -> Self
pub fn with_metric_level(self, metric_level: MetricLevel) -> Self
Sets the metric level for the cache’s metrics.
Defaults to MetricLevel::default.