pub struct BlockCachePolicy { /* private fields */ }Expand description
Controls block-cache insertion for memtable flush and compaction output.
Implementations
Sourceimpl BlockCachePolicy
impl BlockCachePolicy
Sourcepub fn with_flush_targets(self, targets: &[CacheTarget]) -> Self
pub fn with_flush_targets(self, targets: &[CacheTarget]) -> Self
Sets the targets requested for insertion after a memtable flush. An empty slice disables insertion.
Sourcepub fn with_compaction_output_targets(self, targets: &[CacheTarget]) -> Self
pub fn with_compaction_output_targets(self, targets: &[CacheTarget]) -> Self
Sets the targets requested for insertion as compaction output is written. An empty slice disables insertion.